==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/Tests/VisualTests/VTests/src/TransparencyTest.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#include "TransparencyTest.h"

TransparencyTest::TransparencyTest()
{
    mInfo["Title"] = "VTests_Transparency";
    mInfo["Description"] = "Tests basic alpha blending.";
    addScreenshotFrame(25);
}
//---------------------------------------------------------------------------

void TransparencyTest::setupContent()
{
    mSceneMgr->setSkyBox(true, "Examples/TrippySkyBox");

    mCamera->setPosition(0, 0, 300);   // set camera's starting position

    mSceneMgr->createLight()->setPosition(20, 80, 50);   // add basic point light

    // create a torus knot model, give it the translucent texture, and attach it to the origin
    Entity* ent = mSceneMgr->createEntity("Knot", "knot.mesh");
    ent->setMaterialName("Examples/WaterStream");
    mSceneMgr->getRootSceneNode()->attachObject(ent);
}
//-----------------------------------------------------------------------

==> ogre-1.12_1.12.4+dfsg1.orig.tar.xz: ogre-1.12/Tests/VisualTests/VTests/src/TransparencyTest.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#include "TransparencyTest.h"

TransparencyTest::TransparencyTest()
{
    mInfo["Title"] = "VTests_Transparency";
    mInfo["Description"] = "Tests basic alpha blending.";
    addScreenshotFrame(25);
}
//---------------------------------------------------------------------------

void TransparencyTest::setupContent()
{
    mSceneMgr->setSkyBox(true, "Examples/TrippySkyBox");

    mCameraNode->setPosition(0, 0, 300);   // set camera's starting position

    mSceneMgr->getRootSceneNode()
        ->createChildSceneNode(Vector3(20, 80, 50))
        ->attachObject(mSceneMgr->createLight()); // add basic point light

    // create a torus knot model, give it the translucent texture, and attach it to the origin
    Entity* ent = mSceneMgr->createEntity("Knot", "knot.mesh");
    ent->setMaterialName("Examples/WaterStream");
    mSceneMgr->getRootSceneNode()->attachObject(ent);
}
//-----------------------------------------------------------------------
